@@ -8,7 +8,10 @@ import numpy as np
 import sys
 import importlib.resources
 from urllib.parse import urlparse
-from custom_exceptions.veevanetwork_exceptions import *
+try:
+    from custom_exceptions.veevanetwork_exceptions import *
+except:
+    from veevanetwork.custom_exceptions.veevanetwork_exceptions import *
 
 class Vn:
     def __init__(self):
